# Core Dependencies

Dependency classes are a convention in the Mountaineer ecosystem. They provide common functions
that you might want to use at runtime, either in your `render` or `sideeffect` functions.

::: mountaineer.dependencies.CoreDependencies

::: mountaineer.Depends
